/*
 * MITRACE.H -- Illustra trace facility
 *
 *     Copyright c 1995 Illustra Information Technologies, Inc.
 *     All rights reserved.      See files/copyright.
 *
 *
 * 	Flags 0-49 are reserved for use by the application.  They can
 * 	be reused by different applications, and the user may grab
 * 	them as desired.
 *
 * 	Flags 50 up are reserved for library use.
 */

#ifndef _MITRACE_H_
#define _MITRACE_H_

/* tracing vector */
#define MI_TFMAXFLAGS	100		/* size of trace vector */

typedef struct mi_tracevect
{
    mi_integer		tv_numel;
    void		*tv_file; 
    mi_integer (MI_PROC_VACALLBACK *tv_prfunc)
				ARGS((const char MI_FAR *fmt, ...));
    MI_CONNECTION	*tv_conn;
    char		tv_vect[MI_TFMAXFLAGS];
} MI_TRACE_VECTOR;


#ifndef MI_TV
#define MI_TV   (*mi_trace_getvect())
#endif /* ! MI_TV */

EXTERNC_BEGIN

void MI_PROC_EXPORT mi_trace ARGS((const char MI_FAR *s));
mi_integer MI_PROC_VAEXPORT mi_def_tprintf ARGS((const char MI_FAR *fmt, ...));
MI_TRACE_VECTOR MI_FAR * MI_FAR * MI_PROC_EXPORT mi_trace_getvect ARGS((void));

EXTERNC_END


/* Printing function */
#ifndef __cplusplus
#define MI_TPRINTF \
    ((MI_TV != NULL) && (MI_TV->tv_prfunc != NULL) \
     ? MI_TV->tv_prfunc : mi_def_tprintf)
#else /* __cplusplus */
#define MI_TPRINTF mi_def_tprintf
#endif /* __cplusplus */


#ifndef MITRACE_OFF

/* flag is at least rev */
#define MI_TFLAG(flag, lev) \
    ((MI_TV != NULL && flag <= MI_TV->tv_numel) \
     ? MI_TV->tv_vect[flag] >= lev : 0)

/* return the level of flag */
#define MI_TFLEV(flag) \
    ((MI_TV != NULL && flag <= MI_TV->tv_numel) \
     ? MI_TV->tv_vect[flag] : 0)

#define MI_DPRINTF(flag, level, args) \
    if (MI_TFLAG(flag, level)) \
        MI_TPRINTF args

#else /* MITRACE_OFF */

#define MI_TFLAG(flag, lev)		MI_FALSE
#define MI_TFLEV(flag)			0
#define MI_DPRINTF(flag, level, args)	/* do nothing */

#endif /* MITRACE_OFF */

#endif /* _MITRACE_H_ */
